/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  addMember: '添加成员',
  modifyMember: '编辑成员',
  deleteMember: '删除成员',
  deletePopConfirm: '确定要删除这个成员 ?',
  add: '添加',
  success: '成功',
  fail: '失败',
  table: {
    title: '成员列表',
    userName: '用户',
    roleName: '角色',
    createTime: '创建时间',
    modifyTime: '修改时间',
  },
  userNameRequire: '请选择用户',
  roleRequire: '请选择角色',
};
